@@ -7,16 +7,17 @@ horizonplot <- function(x, data, ...)
 
 horizonplot.default <-
     function(x, data = NULL, ...,
+             nbands = 3L,
              horizonscale = NA,
              origin = function(y) na.omit(y)[1],
              colorkey = FALSE, legend = NULL,
              panel = panel.horizonplot,
              prepanel = prepanel.horizonplot,
-             col.regions = c("#B41414","#E03231","#F7A99C","#9FC8DC","#468CC8","#0165B3"),
+             col.regions = brewer.pal(n = 2 * nbands, name = "RdYlBu"),
              strip = FALSE, strip.left = TRUE,
              par.strip.text = list(cex = 0.6),
              colorkey.digits = 3,
-             #layout = c(1, NA), ## TODO pending new lattice release
+             layout = c(1, NA),
              groups = NULL,
              default.scales =
                list(y = list(relation = "free", axs = "i",
@@ -30,46 +31,44 @@ horizonplot.default <-
                   col.regions = col.regions,
                   strip = strip, strip.left = strip.left,
                   par.strip.text = par.strip.text,
-                  #layout = layout,
-                  default.scales = default.scales)
+                  layout = layout,
+                  default.scales = default.scales,
+                  nbands = nbands)
     ans$call <- match.call()
     ## add colorkey
-    if (isTRUE(colorkey)) {
-        colorkey <- list()
-    }
-    if (is.list(colorkey)) {
+    if (isTRUE(colorkey)) colorkey <- list()
+    if (is.list(colorkey))
+    {
+        bands.at <- seq(-nbands, nbands)
         if (ans$y.scales$relation == "same") {
             origin <- ans$y.limits[1]
             horizonscale <- diff(ans$y.limits)
         }
         if (is.na(horizonscale)) {
-            labels <- expression(
-                - 3 * Delta[i], - 2 * Delta[i], - 1 * Delta[i], 0,
-                + 1 * Delta[i], + 2 * Delta[i], + 3 * Delta[i], 0)
+            ## labels <- expression(
+            ##    - 3 * Delta[i], - 2 * Delta[i], - 1 * Delta[i], 0,
+            ##    + 1 * Delta[i], + 2 * Delta[i], + 3 * Delta[i], 0)
+            labels <- parse(text = sprintf("%+d * Delta[i]", bands.at))
+            labels[nbands + 1] <- if (is.numeric(origin)) origin else "origin"
+        }
+        else {
             if (is.numeric(origin)) {
-                labels[4] <- origin
+                labels <- round(origin + bands.at * horizonscale, colorkey.digits)
             } else {
-                labels[4] <- "origin"
-            }
-        } else {
-            if (is.numeric(origin)) {
-                labels <- round(origin + (-3:3) * horizonscale, colorkey.digits)
-            } else {
-                labels <- paste(ifelse(-3:3>=0,"+","-"),
-                                round(abs(-3:3) * horizonscale, colorkey.digits))
-                labels[4] <- "origin"
+                labels <- sprintf("%+g", round(bands.at * horizonscale, colorkey.digits))
+                labels[nbands + 1] <- "origin"
             }
         }
-        ii <- round((0:5 / 5) * (length(col.regions)-1)) + 1
+        ii <- round(seq(1, length(col.regions), length.out = 2 * nbands))
         colorkey <-
-            modifyList(list(col = col.regions[ii], at = -3:3,
-                            labels = list(labels = labels, at = -3:3)),
+            modifyList(list(col = col.regions[ii], at = bands.at,
+                            labels = list(labels = labels, at = bands.at)),
                        colorkey)
         space <- colorkey$space
         if (is.null(space)) space <- "right"
         if (is.null(legend)) legend <- list()
         legend[[space]] <- list(fun = "draw.colorkey",
-                                args = list(colorkey))
+                                args = list(colorkey)) 
         ans <- update(ans, legend = legend)
     }
     ans
@@ -78,15 +77,18 @@ horizonplot.default <-
 
 panel.horizonplot <-
     function(x, y, ..., border = NA,
-             col.regions = c("#B41414","#E03231","#F7A99C","#9FC8DC","#468CC8","#0165B3"),
+             nbands = 3L,
+             col.regions = brewer.pal(n = 2 * nbands, name = "RdYlBu"),
              origin) ## catch origin, don't pass to panel.xyarea!
 {
-    regions <- trellis.par.get("regions")
-    origin <- current.panel.limits()$y[1]
-    scale <- diff(current.panel.limits()$y)
+    origin <- current.panel.limits()$ylim[1]
+    scale <- diff(current.panel.limits()$ylim)
     ## ordered for drawing, from least extreme to most extreme
-    sections <- c(0, -1, 1, -2, 2, -3) ## these are the lower bounds
-    ii <- round(((sections + 3) / 5) * (length(col.regions)-1)) + 1
+    #sections <- c(0, -1, 1, -2, 2, -3) ## these are the lower bounds
+    sections <- as.vector(rbind(seq_len(nbands)-1, -seq_len(nbands)))
+    #ii <- round(((sections + 3) / 5) * (length(col.regions)-1)) + 1
+    ii <- round(((sections + nbands) / (2*nbands-1)) * (length(col.regions)-1)) + 1
+    #ii <- sections + nbands + 1
     col <- col.regions[ii]
     for (i in seq_along(sections)) {
         section <- sections[i]
@@ -106,13 +108,14 @@ panel.horizonplot <-
 
 prepanel.horizonplot <-
     function(x, y, ..., horizonscale = NA,
+             nbands = 3L,
              origin = function(y) na.omit(y)[1])
 {
     if (is.function(origin))
         origin <- origin(y)
     ans <- prepanel.default.xyplot(x, y, ...)
     if (is.na(horizonscale))
-        horizonscale <- max(abs(ans$ylim - origin)) / 3
+        horizonscale <- max(abs(ans$ylim - origin)) / nbands
     ans$ylim <- origin + c(0, horizonscale)
     ans
 }
